
# This file was generated by 'versioneer.py' (0.7+) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

version_version = 'v0.1.0'
version_full = '2ec467a6f5d61ae4ad94638eccece47ab4db3fc4'
def get_versions(default={}, verbose=False):
    return {'version': version_version, 'full': version_full}

